#
# Patch for CMFQuickInstaller version < 1.5.5
#


from AccessControl import ClassSecurityInfo
from Products.CMFQuickInstallerTool.QuickInstallerTool import QuickInstallerTool
from Products.CMFCore.CMFCorePermissions import ManagePortal
from Products.CMFQuickInstallerTool.QuickInstallerTool import not_installed
from Acquisition import aq_parent

class PatchedQuickInstallerTool:
    #
    #   Quick Installer
    #

    security = ClassSecurityInfo()

    security.declareProtected(ManagePortal, 'checkProductIsRestricted')
    def checkProductIsRestricted(self, p):
        """ Check whether product 'p' is allowed for installation.
        Restricted product list is found in property cmf_quickinstaller_restrictions.
        This property should be placed in the Zope root to be modified only
        by the Zope instance manager but not by the CMF/Plone instance managers
        """
        restricted = 0   # not restricted by default
        restrictions = getattr(self.getPhysicalRoot(), 'cmf_quickinstaller_restrictions', ())
        if restrictions:
            site_id = getattr(aq_parent(self), 'id', '')
            if site_id:
                for restriction in restrictions:
                    rproduct, rsites = restriction.split('|')
                    rsites = rsites.split(',')
                    if (rproduct == p) and (site_id not in rsites):
                        restricted = 1
                        break
        return restricted

    security.declareProtected(ManagePortal, 'listInstallableProducts')
    def listInstallableProducts(self,skipInstalled=1):
        """List candidate CMF products for
        installation -> list of dicts with keys:(id,hasError,status)
        """
        pids = self.Control_Panel.Products.objectIds() + not_installed(self)

        pids = [pid for pid in pids if self.isProductInstallable(pid)]

        if skipInstalled:
            installed=[p['id'] for p in self.listInstalledProducts(showHidden=1)]
            pids=[r for r in pids if r not in installed]

        # the following one line is CMFQIProductsRestriction patch
        pids=[r for r in pids if not self.checkProductIsRestricted(r)]

        res=[]
        for r in pids:
            p=self._getOb(r,None)
            if p:
                res.append({'id':r, 'status':p.getStatus(),
                            'hasError':p.hasError()})
            else:
                res.append({'id':r, 'status':'new', 'hasError':0})
        return res
