#
# This module is copied and from PloneHelpCenter product and modified 
# for CMFQuickInstaller product
#
from AccessControl import ClassSecurityInfo
from Products.CMFQuickInstallerTool.QuickInstallerTool import QuickInstallerTool
from Products.CMFCore.CMFCorePermissions import ManagePortal

PATCH_PREFIX = '_monkey_'

__refresh_module__ = 0


def monkeyPatch(originalClass, patchingClass):
    #print 'monkeyPatch', originalClass.__name__, patchingClass.__name__
    """Monkey patch original class with attributes from new class
       (Swiped from SpeedPack -- thanks, Christian Heimes!)

    * Takes all attributes and methods except __doc__ and __module__ from patching class
    * Safes original attributes as _monkey_name
    * Overwrites/adds these attributes in original class
    """
    for name, newAttr in patchingClass.__dict__.items():
        # don't overwrite doc or module informations
        if name not in ('__doc__', '__module__'):
            # safe the old attribute as __monkey_name if exists
            # __dict__ doesn't show inherited attributes :/
            orig = getattr(originalClass, name, None)
            if orig:
                stored_orig_name = PATCH_PREFIX + name
                stored_orig = getattr(originalClass, stored_orig_name, None)
                # don't double-patch on refresh!
                if stored_orig is None:
                    originalClass.__dict__[stored_orig_name] = orig
            # overwrite or add the new attribute
            originalClass.__dict__[name] = newAttr



import zLOG
from Products.CMFQuickInstallerTool import quickinstaller_globals
from App.Common import package_home
from os.path import join

x = []
QI_VERSION = 'Unknown'
try:
    file = join(package_home(quickinstaller_globals), 'version.txt')
    QI_VERSION = open(file, 'r').read().strip()
    version = QI_VERSION.strip()
    if version.lower().startswith('cmf-'):
        version = version[4:]
    filtered = ''
    for v in version:
        if v in ['0','1','2','3','4','5','6','7','8','9','.']:
            filtered += v
        else:
            break
    x = [int(x) for x in filtered.split('.')]
except IOError:
    # couldnt find file, oh well
    pass
except ValueError:
    # couldnt make sense of the version number
    pass

if [1,5,0] <= x <= [1,5,4]:
    zLOG.LOG('CMFQIProductsRestrictions', zLOG.INFO, 'Monkey patching CMFQuickInstallerTool (patch A - version %s)' % x)
    from Products.CMFQIProductsRestrictions.Patch_1_5_4 import PatchedQuickInstallerTool
    monkeyPatch(QuickInstallerTool, PatchedQuickInstallerTool)
elif x == [1,5,5]:
    zLOG.LOG('CMFQIProductsRestrictions', zLOG.INFO, 'Monkey patching CMFQuickInstallerTool (patch B - version %s)' % x)
    from Products.CMFQIProductsRestrictions.Patch_1_5_5 import PatchedQuickInstallerTool
    monkeyPatch(QuickInstallerTool, PatchedQuickInstallerTool)
else:
    #raise 'CMFQIProductsRestrictions patch should be used only qith CMFQuickInstallerTool 1.5.2. Please check patched methods'
    zLOG.LOG('CMFQIProductsRestrictions', zLOG.WARNING, 'Monkey patch CMFQuickInstallerTool NOT APPLIED - This patch is only for versions 1.5.2 to 1.5.5, but this is version %s' % x)

